From cd672f8feb4c533c2ef1bbfb31088efc64ce7160 Mon Sep 17 00:00:00 2001
From: Michael Paquier <michael@paquier.xyz>
Date: Wed, 18 Jan 2023 14:37:07 +0900
Subject: [PATCH v3 2/3] Move query jumble code to src/backend/nodes/

This will ease a follow-up move that will generate automatically this
code:
- queryjumble.c -> queryjumblefuncs.c
- utils/queryjumble.h -> nodes/queryjumble.h
---
 src/include/{utils => nodes}/queryjumble.h                  | 2 +-
 src/include/parser/analyze.h                                | 2 +-
 src/backend/nodes/Makefile                                  | 1 +
 src/backend/nodes/meson.build                               | 1 +
 .../{utils/misc/queryjumble.c => nodes/queryjumblefuncs.c}  | 6 +++---
 src/backend/parser/analyze.c                                | 2 +-
 src/backend/postmaster/postmaster.c                         | 2 +-
 src/backend/utils/misc/Makefile                             | 1 -
 src/backend/utils/misc/guc_tables.c                         | 2 +-
 src/backend/utils/misc/meson.build                          | 1 -
 contrib/pg_stat_statements/pg_stat_statements.c             | 2 +-
 11 files changed, 11 insertions(+), 11 deletions(-)
 rename src/include/{utils => nodes}/queryjumble.h (98%)
 rename src/backend/{utils/misc/queryjumble.c => nodes/queryjumblefuncs.c} (99%)

diff --git a/src/include/utils/queryjumble.h b/src/include/nodes/queryjumble.h
similarity index 98%
rename from src/include/utils/queryjumble.h
rename to src/include/nodes/queryjumble.h
index d372801410..204b8f74fd 100644
--- a/src/include/utils/queryjumble.h
+++ b/src/include/nodes/queryjumble.h
@@ -7,7 +7,7 @@
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  * IDENTIFICATION
- *	  src/include/utils/queryjumble.h
+ *	  src/include/nodes/queryjumble.h
  *
  *-------------------------------------------------------------------------
  */
diff --git a/src/include/parser/analyze.h b/src/include/parser/analyze.h
index c97be6efcf..1cef1833a6 100644
--- a/src/include/parser/analyze.h
+++ b/src/include/parser/analyze.h
@@ -15,8 +15,8 @@
 #define ANALYZE_H
 
 #include "nodes/params.h"
+#include "nodes/queryjumble.h"
 #include "parser/parse_node.h"
-#include "utils/queryjumble.h"
 
 /* Hook for plugins to get control at end of parse analysis */
 typedef void (*post_parse_analyze_hook_type) (ParseState *pstate,
diff --git a/src/backend/nodes/Makefile b/src/backend/nodes/Makefile
index 7c594be583..af12c64878 100644
--- a/src/backend/nodes/Makefile
+++ b/src/backend/nodes/Makefile
@@ -27,6 +27,7 @@ OBJS = \
 	outfuncs.o \
 	params.o \
 	print.o \
+	queryjumblefuncs.o \
 	read.o \
 	readfuncs.o \
 	tidbitmap.o \
diff --git a/src/backend/nodes/meson.build b/src/backend/nodes/meson.build
index 2ff7dbac1d..9230515e7f 100644
--- a/src/backend/nodes/meson.build
+++ b/src/backend/nodes/meson.build
@@ -10,6 +10,7 @@ backend_sources += files(
   'nodes.c',
   'params.c',
   'print.c',
+  'queryjumblefuncs.c',
   'read.c',
   'tidbitmap.c',
   'value.c',
diff --git a/src/backend/utils/misc/queryjumble.c b/src/backend/nodes/queryjumblefuncs.c
similarity index 99%
rename from src/backend/utils/misc/queryjumble.c
rename to src/backend/nodes/queryjumblefuncs.c
index 328995a7dc..16084842a3 100644
--- a/src/backend/utils/misc/queryjumble.c
+++ b/src/backend/nodes/queryjumblefuncs.c
@@ -1,6 +1,6 @@
 /*-------------------------------------------------------------------------
  *
- * queryjumble.c
+ * queryjumblefuncs.c
  *	 Query normalization and fingerprinting.
  *
  * Normalization is a process whereby similar queries, typically differing only
@@ -26,7 +26,7 @@
  *
  *
  * IDENTIFICATION
- *	  src/backend/utils/misc/queryjumble.c
+ *	  src/backend/nodes/queryjumblefuncs.c
  *
  *-------------------------------------------------------------------------
  */
@@ -34,8 +34,8 @@
 
 #include "common/hashfn.h"
 #include "miscadmin.h"
+#include "nodes/queryjumble.h"
 #include "parser/scansup.h"
-#include "utils/queryjumble.h"
 
 #define JUMBLE_SIZE				1024	/* query serialization buffer size */
 
diff --git a/src/backend/parser/analyze.c b/src/backend/parser/analyze.c
index 5b90974e83..4a817b75ad 100644
--- a/src/backend/parser/analyze.c
+++ b/src/backend/parser/analyze.c
@@ -30,6 +30,7 @@
 #include "miscadmin.h"
 #include "nodes/makefuncs.h"
 #include "nodes/nodeFuncs.h"
+#include "nodes/queryjumble.h"
 #include "optimizer/optimizer.h"
 #include "parser/analyze.h"
 #include "parser/parse_agg.h"
@@ -50,7 +51,6 @@
 #include "utils/backend_status.h"
 #include "utils/builtins.h"
 #include "utils/guc.h"
-#include "utils/queryjumble.h"
 #include "utils/rel.h"
 #include "utils/syscache.h"
 
diff --git a/src/backend/postmaster/postmaster.c b/src/backend/postmaster/postmaster.c
index 9cedc1b9f0..f05a26d255 100644
--- a/src/backend/postmaster/postmaster.c
+++ b/src/backend/postmaster/postmaster.c
@@ -102,6 +102,7 @@
 #include "libpq/libpq.h"
 #include "libpq/pqformat.h"
 #include "libpq/pqsignal.h"
+#include "nodes/queryjumble.h"
 #include "pg_getopt.h"
 #include "pgstat.h"
 #include "port/pg_bswap.h"
@@ -126,7 +127,6 @@
 #include "utils/memutils.h"
 #include "utils/pidfile.h"
 #include "utils/ps_status.h"
-#include "utils/queryjumble.h"
 #include "utils/timeout.h"
 #include "utils/timestamp.h"
 #include "utils/varlena.h"
diff --git a/src/backend/utils/misc/Makefile b/src/backend/utils/misc/Makefile
index b9ee4eb48a..2910032930 100644
--- a/src/backend/utils/misc/Makefile
+++ b/src/backend/utils/misc/Makefile
@@ -26,7 +26,6 @@ OBJS = \
 	pg_rusage.o \
 	ps_status.o \
 	queryenvironment.o \
-	queryjumble.o \
 	rls.o \
 	sampling.o \
 	superuser.o \
diff --git a/src/backend/utils/misc/guc_tables.c b/src/backend/utils/misc/guc_tables.c
index 5025e80f89..f9bfbbbd95 100644
--- a/src/backend/utils/misc/guc_tables.c
+++ b/src/backend/utils/misc/guc_tables.c
@@ -43,6 +43,7 @@
 #include "jit/jit.h"
 #include "libpq/auth.h"
 #include "libpq/libpq.h"
+#include "nodes/queryjumble.h"
 #include "optimizer/cost.h"
 #include "optimizer/geqo.h"
 #include "optimizer/optimizer.h"
@@ -77,7 +78,6 @@
 #include "utils/pg_locale.h"
 #include "utils/portal.h"
 #include "utils/ps_status.h"
-#include "utils/queryjumble.h"
 #include "utils/inval.h"
 #include "utils/xml.h"
 
diff --git a/src/backend/utils/misc/meson.build b/src/backend/utils/misc/meson.build
index e3e99ec5cb..f719c97c05 100644
--- a/src/backend/utils/misc/meson.build
+++ b/src/backend/utils/misc/meson.build
@@ -11,7 +11,6 @@ backend_sources += files(
   'pg_rusage.c',
   'ps_status.c',
   'queryenvironment.c',
-  'queryjumble.c',
   'rls.c',
   'sampling.c',
   'superuser.c',
diff --git a/contrib/pg_stat_statements/pg_stat_statements.c b/contrib/pg_stat_statements/pg_stat_statements.c
index a7a72783e5..ad1fe44496 100644
--- a/contrib/pg_stat_statements/pg_stat_statements.c
+++ b/contrib/pg_stat_statements/pg_stat_statements.c
@@ -55,6 +55,7 @@
 #include "jit/jit.h"
 #include "mb/pg_wchar.h"
 #include "miscadmin.h"
+#include "nodes/queryjumble.h"
 #include "optimizer/planner.h"
 #include "parser/analyze.h"
 #include "parser/parsetree.h"
@@ -69,7 +70,6 @@
 #include "tcop/utility.h"
 #include "utils/acl.h"
 #include "utils/builtins.h"
-#include "utils/queryjumble.h"
 #include "utils/memutils.h"
 #include "utils/timestamp.h"
 
-- 
2.39.0

